<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Conversa</translation>
    </message>
    <message>
        <source>Words fix</source>
        <translation>Correção de palavras</translation>
    </message>
    <message>
        <source>Enable word fix</source>
        <translation>Habilitar correção de palavras</translation>
    </message>
    <message>
        <source>Spelling</source>
        <translation>Ortografia</translation>
    </message>
</context>
<context>
    <name>WordFixConfigurationUiHandler</name>
    <message>
        <source>A word to be replaced</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Value to replace with</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Add</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Change</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Word</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Replace with</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>